@@ -290,19 +290,19 @@ GstPadTemplate*		gst_element_get_pad_template		(GstElement *element, const gchar
 GList*			gst_element_get_pad_template_list	(GstElement *element);
 GstPadTemplate*		gst_element_get_compatible_pad_template (GstElement *element, GstPadTemplate *compattempl);
 
-gboolean		gst_element_connect		(GstElement *src, GstElement *dest);
-gboolean		gst_element_connect_many 	(GstElement *element_1, GstElement *element_2, ...);
-gboolean		gst_element_connect_filtered 	(GstElement *src, GstElement *dest,
+gboolean		gst_element_link		(GstElement *src, GstElement *dest);
+gboolean		gst_element_link_many 		(GstElement *element_1, GstElement *element_2, ...);
+gboolean		gst_element_link_filtered 	(GstElement *src, GstElement *dest,
 							 GstCaps *filtercaps);
-void			gst_element_disconnect 		(GstElement *src, GstElement *dest);
-void			gst_element_disconnect_many 	(GstElement *element_1, GstElement *element_2, ...);
+void			gst_element_unlink 		(GstElement *src, GstElement *dest);
+void			gst_element_unlink_many 	(GstElement *element_1, GstElement *element_2, ...);
 
-gboolean		gst_element_connect_pads	(GstElement *src, const gchar *srcpadname,
+gboolean		gst_element_link_pads		(GstElement *src, const gchar *srcpadname,
 							 GstElement *dest, const gchar *destpadname);
-gboolean		gst_element_connect_pads_filtered (GstElement *src, const gchar *srcpadname,
+gboolean		gst_element_link_pads_filtered 	(GstElement *src, const gchar *srcpadname,
 							 GstElement *dest, const gchar *destpadname,
 							 GstCaps *filtercaps);
-void			gst_element_disconnect_pads	(GstElement *src, const gchar *srcpadname,
+void			gst_element_unlink_pads		(GstElement *src, const gchar *srcpadname,
 							 GstElement *dest, const gchar *destpadname);
 
 const GstEventMask*	gst_element_get_event_masks	(GstElement *element);
