@@ -91,7 +91,7 @@ enum {
   GST_CAT_CLOCK,		/* Clocking */
   GST_CAT_ELEMENT_PADS,		/* Element pad management */
   GST_CAT_ELEMENT_FACTORY,	/* Elementfactory stuff */
-  GST_CAT_PADS,			/* Pad creation/connection */
+  GST_CAT_PADS,			/* Pad creation/linking */
   GST_CAT_PIPELINE,		/* Pipeline stuff */
   GST_CAT_PLUGIN_LOADING,	/* Plugin loading */
   GST_CAT_PLUGIN_ERRORS,	/* Errors during plugin loading */
@@ -207,11 +207,11 @@ G_GNUC_UNUSED static gchar *_debug_string = NULL;
 #ifdef G_HAVE_ISO_VARARGS
 
 #ifdef GST_DEBUG_COLOR
-  #define GST_DEBUG_ENTER(...) GST_DEBUG( 31 , "\033[00;37mentering\033[00m :" __VA_ARGS__ )
-  #define GST_DEBUG_LEAVE(...) GST_DEBUG( 31 , "\033[00;37mleaving\033[00m :"  __VA_ARGS__ )
+  #define GST_DEBUG_ENTER(...) GST_DEBUG( 31 , "\033[00;37mentering\033[00m: " __VA_ARGS__ )
+  #define GST_DEBUG_LEAVE(...) GST_DEBUG( 31 , "\033[00;37mleaving\033[00m: "  __VA_ARGS__ )
 #else
-  #define GST_DEBUG_ENTER(...) GST_DEBUG( 31 , "entering :" __VA_ARGS__ )
-  #define GST_DEBUG_LEAVE(...) GST_DEBUG( 31 , "leaving :" __VA_ARGS__ )
+  #define GST_DEBUG_ENTER(...) GST_DEBUG( 31 , "entering: " __VA_ARGS__ )
+  #define GST_DEBUG_LEAVE(...) GST_DEBUG( 31 , "leaving: " __VA_ARGS__ )
 #endif
 
 #elif defined(G_HAVE_GNUC_VARARGS)
@@ -352,8 +352,6 @@ void gst_default_info_handler (gint category,gboolean incore,
                                gint line,const gchar *debug_string,
                                void *element,gchar *string);
 
-inline void * _gst_debug_register_funcptr (void *ptr, gchar *ptrname);
-
 extern GstInfoHandler _gst_info_handler;
 extern guint32 _gst_info_categories;
 
@@ -458,13 +456,11 @@ extern GstErrorHandler _gst_error_handler;
 
 #endif
 
-
-
-
 /********** function pointer stuff **********/
-extern GHashTable *__gst_function_pointers;
-
 #if GST_DEBUG_ENABLED
+void* 		_gst_debug_register_funcptr 	(void *ptr, gchar *ptrname);
+gchar*		_gst_debug_nameof_funcptr 	(void *ptr);
+
 #define GST_DEBUG_FUNCPTR(ptr) _gst_debug_register_funcptr((void *)(ptr), #ptr)
 #define GST_DEBUG_FUNCPTR_NAME(ptr) _gst_debug_nameof_funcptr((void *)ptr)
 #else
@@ -472,8 +468,6 @@ extern GHashTable *__gst_function_pointers;
 #define GST_DEBUG_FUNCPTR_NAME(ptr) ""
 #endif /* GST_DEBUG_ENABLED */
 
-gchar *_gst_debug_nameof_funcptr (void *ptr);
-
 void gst_debug_print_stack_trace (void);
 
 #endif /* __GSTINFO_H__ */
