@@ -147,8 +147,8 @@ gst_object_class_init (GstObjectClass *klass)
   klass->path_string_separator = "/";
 
   klass->signal_object = g_object_new (gst_signal_object_get_type (), NULL);
-    /* see the comments at gst_element_dispatch_properties_changed */
 
+  /* see the comments at gst_element_dispatch_properties_changed */
   gobject_class->dispatch_properties_changed
 	        = GST_DEBUG_FUNCPTR (gst_object_dispatch_properties_changed);
 
@@ -180,8 +180,10 @@ gst_object_ref (GstObject *object)
 {
   g_return_val_if_fail (GST_IS_OBJECT (object), NULL);
 
-  GST_DEBUG (GST_CAT_REFCOUNTING, "ref '%s' %d->%d",GST_OBJECT_NAME(object),
-             G_OBJECT(object)->ref_count,G_OBJECT(object)->ref_count+1);
+  GST_DEBUG (GST_CAT_REFCOUNTING, "ref %p '%s' %d->%d", object,
+	     GST_OBJECT_NAME (object),
+             G_OBJECT (object)->ref_count,
+	     G_OBJECT (object)->ref_count + 1);
 
   g_object_ref (G_OBJECT (object));
   return object;
@@ -198,9 +200,12 @@ void
 gst_object_unref (GstObject *object)
 {
   g_return_if_fail (GST_IS_OBJECT (object));
+  g_return_if_fail (G_OBJECT (object)->ref_count > 0);
 
-  GST_DEBUG (GST_CAT_REFCOUNTING, "unref '%s' %d->%d",GST_OBJECT_NAME(object),
-             G_OBJECT(object)->ref_count,G_OBJECT(object)->ref_count-1);
+  GST_DEBUG (GST_CAT_REFCOUNTING, "unref %p '%s' %d->%d", object,
+	     GST_OBJECT_NAME (object),
+             G_OBJECT (object)->ref_count,
+	     G_OBJECT (object)->ref_count - 1);
 
   g_object_unref (G_OBJECT (object));
 }
@@ -220,14 +225,35 @@ gst_object_sink (GstObject *object)
   g_return_if_fail (object != NULL);
   g_return_if_fail (GST_IS_OBJECT (object));
 
-  GST_DEBUG (GST_CAT_REFCOUNTING, "sink '%s'",GST_OBJECT_NAME(object));
-  if (GST_OBJECT_FLOATING (object))
-  {
+  GST_DEBUG (GST_CAT_REFCOUNTING, "sink %p '%s'", object, GST_OBJECT_NAME (object));
+
+  if (GST_OBJECT_FLOATING (object)) {
     GST_FLAG_UNSET (object, GST_FLOATING);
     gst_object_unref (object);
   }
 }
 
+/**
+ * gst_object_swap:
+ * @oldobj: pointer to place of old GstObject
+ * @newobj: new GstObject
+ *
+ * Unrefs the object pointer to by oldobj, refs the newobj and
+ * puts the newobj in *oldobj.
+ */
+void
+gst_object_swap (GstObject **oldobj, GstObject *newobj)
+{
+  if (*oldobj != newobj) {
+    if (newobj)
+      gst_object_ref (newobj);
+    if (*oldobj)
+      gst_object_unref (*oldobj);
+
+    *oldobj = newobj;
+  }
+}
+
 /**
  * gst_object_destroy:
  * @object: GstObject to destroy
@@ -241,7 +267,8 @@ gst_object_destroy (GstObject *object)
   g_return_if_fail (object != NULL);
   g_return_if_fail (GST_IS_OBJECT (object));
 
-  GST_DEBUG (GST_CAT_REFCOUNTING, "destroy '%s'",GST_OBJECT_NAME(object));
+  GST_DEBUG (GST_CAT_REFCOUNTING, "destroy %p '%s'", object, GST_OBJECT_NAME (object));
+
   if (!GST_OBJECT_DESTROYED (object))
   {
     /* need to hold a reference count around all class method
@@ -254,7 +281,8 @@ gst_object_destroy (GstObject *object)
 static void
 gst_object_dispose (GObject *object)
 {
-  GST_DEBUG (GST_CAT_REFCOUNTING, "dispose '%s'",GST_OBJECT_NAME(object));
+  GST_DEBUG (GST_CAT_REFCOUNTING, "dispose %p '%s'", object, GST_OBJECT_NAME (object));
+  
   GST_FLAG_SET (GST_OBJECT (object), GST_DESTROYED);
   GST_OBJECT_PARENT (object) = NULL;
 
@@ -267,7 +295,7 @@ gst_object_finalize (GObject *object)
 {
   GstObject *gstobject = GST_OBJECT (object);
 
-  GST_DEBUG (GST_CAT_REFCOUNTING, "finalize '%s'",GST_OBJECT_NAME(object));
+  GST_DEBUG (GST_CAT_REFCOUNTING, "finalize %p '%s'", object, GST_OBJECT_NAME (object));
 
   g_signal_handlers_destroy (object);
 
@@ -315,7 +343,8 @@ gst_object_dispatch_properties_changed (GObject     *object,
  * @object: the #GObject that signalled the notify.
  * @orig: a #GstObject that initiated the notify.
  * @pspec: a #GParamSpec of the property.
- * @excluded_props: a set of user-specified properties to exclude.
+ * @excluded_props: a set of user-specified properties to exclude or
+ *  NULL to show all changes.
  *
  * Adds a default deep_notify signal callback to an
  * element. The user data should contain a pointer to an array of
@@ -554,7 +583,8 @@ gst_object_save_thyself (GstObject *object, xmlNodePtr parent)
   g_return_val_if_fail (GST_IS_OBJECT (object), parent);
   g_return_val_if_fail (parent != NULL, parent);
 
-  oclass = (GstObjectClass *)G_OBJECT_GET_CLASS(object);
+  oclass = GST_OBJECT_GET_CLASS (object);
+
   if (oclass->save_thyself)
     oclass->save_thyself (object, parent);
 
@@ -579,7 +609,8 @@ gst_object_restore_thyself (GstObject *object, xmlNodePtr self)
   g_return_if_fail (GST_IS_OBJECT (object));
   g_return_if_fail (self != NULL);
 
-  oclass = (GstObjectClass *) G_OBJECT_GET_CLASS(object);
+  oclass = GST_OBJECT_GET_CLASS (object);
+
   if (oclass->restore_thyself)
     oclass->restore_thyself (object, self);
 }
@@ -591,8 +622,7 @@ gst_object_real_restore_thyself (GstObject *object, xmlNodePtr self)
   g_return_if_fail (GST_IS_OBJECT (object));
   g_return_if_fail (self != NULL);
   
-/* FIXME: the signalobject stuff doesn't work
- *  gst_class_signal_emit_by_name (object, "object_loaded", self); */
+   gst_class_signal_emit_by_name (object, "object_loaded", self);
 }
 #endif /* GST_DISABLE_LOADSAVE_REGISTRY */
 
@@ -682,7 +712,7 @@ gst_object_get_path_string (GstObject *object)
   parents = parentage;
   while (parents) {
     if (GST_IS_OBJECT (parents->data)) {
-      GstObjectClass *oclass = (GstObjectClass *)G_OBJECT_GET_CLASS(parents->data);
+      GstObjectClass *oclass = GST_OBJECT_GET_CLASS (parents->data);
 
       component = gst_object_get_name (parents->data);
       separator = oclass->path_string_separator;
@@ -756,10 +786,10 @@ gst_signal_object_class_init (GstSignalObjectClass *klass)
 
 #ifndef GST_DISABLE_LOADSAVE_REGISTRY
   gst_signal_object_signals[SO_OBJECT_LOADED] =
-    g_signal_new("object_loaded", G_TYPE_FROM_CLASS(klass), G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (GstObjectClass, parent_set), NULL, NULL,
-                  gst_marshal_VOID__OBJECT_POINTER,G_TYPE_NONE,2,
-                  G_TYPE_OBJECT,G_TYPE_POINTER);
+    g_signal_new ("object_loaded", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST,
+                  G_STRUCT_OFFSET (GstSignalObjectClass, object_loaded), NULL, NULL,
+                  gst_marshal_VOID__OBJECT_POINTER, G_TYPE_NONE, 2,
+                  G_TYPE_OBJECT, G_TYPE_POINTER);
 #endif
 }
 
@@ -804,7 +834,7 @@ gst_class_signal_emit_by_name (GstObject *object,
 {
   GstObjectClass *oclass;
 
-  oclass = (GstObjectClass *)G_OBJECT_GET_CLASS(object);
+  oclass = GST_OBJECT_GET_CLASS (object);
 
   g_signal_emit_by_name (oclass->signal_object, name, object, self);
 }
