@@ -361,10 +361,13 @@ gst_plugin_is_loaded (GstPlugin *plugin)
 GstPluginFeature*
 gst_plugin_find_feature (GstPlugin *plugin, const gchar *name, GType type)
 {
-  GList *features = plugin->features;
-
+  GList *features;
+  
+  g_return_val_if_fail (plugin != NULL, NULL);
   g_return_val_if_fail (name != NULL, NULL);
 
+  features = plugin->features;
+
   while (features) {
     GstPluginFeature *feature = GST_PLUGIN_FEATURE (features->data);
 
@@ -436,11 +439,9 @@ gst_plugin_load (const gchar *name)
   GError *error = NULL;
 
   plugin = gst_registry_pool_find_plugin (name);
-  if (plugin)
-  {
+  if (plugin) {
     gboolean result = gst_plugin_load_plugin (plugin, &error);
-    if (error)
-    {
+    if (error) {
       GST_DEBUG (GST_CAT_PLUGIN_LOADING, "load_plugin error: %s\n",
 	         error->message);
       g_error_free (error);
